@@ -1,5 +1,7 @@
 """An advanced setup script to create multiple executables and demonstrate a
-few of the features available to setup scripts."""
+few of the features available to setup scripts.
+"""
+
 #
 # Run the build process by running the command 'python setup.py build'
 #
@@ -7,16 +9,16 @@ few of the features available to setup scripts."""
 # subdirectory that contains the files needed to run the script without Python
 import sys
 
-from cx_Freeze import Executable, setup
+from cx_Freeze import setup
 
 options = {
     "build_exe": {
         "includes": ["testfreeze_1", "testfreeze_2"],
-        "path": sys.path + ["modules"],
+        "path": [*sys.path, "modules"],
     }
 }
 
-executables = [Executable("advanced_1.py"), Executable("advanced_2.py")]
+executables = ["advanced_1.py", "advanced_2.py"]
 
 setup(
     name="advanced_cx_Freeze_sample",
