@@ -1,5 +1,4 @@
-"""
-A simple setup script to create an executable using pandas. This also
+"""A simple setup script to create an executable using pandas. This also
 demonstrates how to use excludes to get minimal package size.
 
 test_pandas.py is a very simple type of pandas application.
@@ -10,7 +9,11 @@ If everything works well you should find a subdirectory in the build
 subdirectory that contains the files needed to run the application.
 """
 
-from cx_Freeze import Executable, setup
+import sys
+
+from cx_Freeze import setup
+
+sys.setrecursionlimit(sys.getrecursionlimit() * 10)
 
 options = {
     "build_exe": {
@@ -18,14 +21,11 @@ options = {
         "excludes": ["tkinter", "unittest", "email", "http", "xml", "pydoc"],
     },
 }
-executables = [
-    Executable("test_pandas.py"),
-]
 
 setup(
     name="test_pandas",
     version="0.1.0.1",
     description="Sample pandas script",
-    executables=executables,
+    executables=["test_pandas.py"],
     options=options,
 )
