@@ -1,5 +1,4 @@
-"""
-A simple setup script to create an executable using PyQt5 QtWebEngineWidgets.
+"""A simple setup script to create an executable using PyQt5 QtWebEngineWidgets.
 This also demonstrates how to use excludes to get minimal package size.
 
 Run the build process by running the command 'python setup.py build'
@@ -10,35 +9,25 @@ subdirectory that contains the files needed to run the application
 
 from __future__ import annotations
 
-import sys
-
 from cx_Freeze import Executable, setup
 
-base = "Win32GUI" if sys.platform == "win32" else None
-
 options = {
     "build_exe": {
         # exclude packages that are not really needed
-        "excludes": [
-            "tkinter",
-            "unittest",
-            "email",
-            "http",
-            "xml",
-            "pydoc",
-        ],
-        "zip_include_packages": ["PyQt5"],
+        "excludes": ["tkinter", "unittest", "email", "http", "xml", "pydoc"]
     },
     "bdist_mac": {"bundle_name": "PyQt5 Webengine Test"},
 }
 
 executables = [
-    Executable("simplebrowser.py", target_name="test_simplebrowser")
+    Executable(
+        "simplebrowser.py", target_name="test_simplebrowser", base="gui"
+    )
 ]
 
 setup(
     name="simplebrowser",
-    version="0.1",
+    version="7.2",
     description="cx_Freeze and PyQt5 Webengine sample",
     options=options,
     executables=executables,
