@@ -8,16 +8,14 @@ If everything works well you should find a subdirectory in the build
 subdirectory that contains the files needed to run the script without Python.
 """
 
-import sys
 from cx_Freeze import Executable, setup
 
-base = "Win32GUI" if sys.platform == "win32" else None
-executables = [Executable("test_tkinter.py", base=base)]
-include_files = [("logox128.png", "icon/python.png")]
+executables = [Executable("test_tkinter.py", base="gui", icon="python")]
+include_files = [("logox128.png", "share/python.png")]
 
 setup(
     name="test_tkinter",
-    version="0.3",
+    version="0.3.2",
     description="Sample cx_Freeze Tkinter script",
     options={"build_exe": {"include_files": include_files}},
     executables=executables,
