@@ -2,17 +2,15 @@
 
 from __future__ import annotations
 
-import sys
-from pathlib import Path
-from sysconfig import get_platform, get_python_version
+from typing import TYPE_CHECKING
 
 from generate_samples import create_package, run_command
 
-PLATFORM = get_platform()
-PYTHON_VERSION = get_python_version()
-BUILD_EXE_DIR = f"build/exe.{PLATFORM}-{PYTHON_VERSION}"
-IS_WINDOWS = sys.platform == "win32"
-SUFFIX = ".exe" if IS_WINDOWS else ""
+from cx_Freeze._compat import BUILD_EXE_DIR, EXE_SUFFIX
+
+if TYPE_CHECKING:
+    from pathlib import Path
+
 
 SOURCE = """
 test_ssl.py
@@ -25,19 +23,19 @@ test_ssl.py
     print(ssl_paths.openssl_cafile)
     print(os.environ.get('SSL_CERT_FILE'))
 setup.py
-    from cx_Freeze import Executable, setup
+    from cx_Freeze import setup
     setup(
-        executables=[Executable("test_ssl.py")],
+        executables=["test_ssl.py"],
         options={"build_exe": {"excludes": ["tkinter"], "silent": True}}
     )
 """
 
 
-def test_ssl(tmp_path: Path):
+def test_ssl(tmp_path: Path) -> None:
     """Test that the ssl is working correctly."""
     create_package(tmp_path, SOURCE)
     output = run_command(tmp_path)
-    executable = tmp_path / BUILD_EXE_DIR / f"test_ssl{SUFFIX}"
+    executable = tmp_path / BUILD_EXE_DIR / f"test_ssl{EXE_SUFFIX}"
     assert executable.is_file()
     output = run_command(tmp_path, executable, timeout=10)
     assert output.splitlines()[0] == "Hello from cx_Freeze"
