@@ -15,8 +15,11 @@ from generate_samples import (
     CODING_EXPLICIT_CP1252_TEST,
     CODING_EXPLICIT_UTF8_TEST,
     EXTENDED_OPARGS_TEST,
+    IMPORT_CALL_TEST,
     MAYBE_TEST,
     MAYBE_TEST_NEW,
+    NAMESPACE_TEST,
+    NESTED_NAMESPACE_TEST,
     PACKAGE_TEST,
     RELATIVE_IMPORT_TEST,
     RELATIVE_IMPORT_TEST_2,
@@ -56,13 +59,10 @@ def _do_test(
     debug=0,  # noqa: ARG001
     modulefinder_class=ModuleFinder,
     **kwargs,
-):
+) -> None:
     create_package(test_dir, source)
     finder = modulefinder_class(
-        ConstantsModule(),
-        path=[test_dir, *sys.path],
-        # debug=debug,
-        **kwargs,
+        ConstantsModule(), path=[test_dir, *sys.path], **kwargs
     )
     finder.include_module(import_this)
     if report:
@@ -72,11 +72,6 @@ def _do_test(
     # check if we found what we expected, not more, not less
     assert found == modules
 
-    # check for missing and maybe missing modules
-    # bad, maybe = finder.any_missing_maybe()
-    # self.assertEqual(bad, missing)
-    # self.assertEqual(maybe, maybe_missing)
-
 
 @pytest.mark.parametrize(
     ("import_this", "modules", "missing", "maybe_missing", "source"),
@@ -86,8 +81,11 @@ def _do_test(
         CODING_EXPLICIT_CP1252_TEST,
         CODING_EXPLICIT_UTF8_TEST,
         EXTENDED_OPARGS_TEST,
+        IMPORT_CALL_TEST,
         MAYBE_TEST,
         MAYBE_TEST_NEW,
+        NAMESPACE_TEST,
+        NESTED_NAMESPACE_TEST,
         PACKAGE_TEST,
         RELATIVE_IMPORT_TEST,
         RELATIVE_IMPORT_TEST_2,
@@ -102,8 +100,11 @@ def _do_test(
         "coding_explicit_cp1252_test",
         "coding_explicit_utf8_test",
         "extended_opargs_test",
+        "import_call_test",
         "maybe_test",
         "maybe_test_new",
+        "namespace_test",
+        "nested_namespace_test",
         "package_test",
         "relative_import_test",
         "relative_import_test_2",
@@ -120,12 +121,12 @@ def test_finder(
     missing,
     maybe_missing,
     source,
-):
+) -> None:
     """Provides test cases for ModuleFinder class."""
     _do_test(tmp_path, import_this, modules, missing, maybe_missing, source)
 
 
-def test_bytecode(tmp_path):
+def test_bytecode(tmp_path) -> None:
     """Provides bytecode test case for ModuleFinder class."""
     base_path = tmp_path / "a"
     source_path = base_path.with_suffix(SOURCE_SUFFIXES[0])
@@ -137,21 +138,23 @@ def test_bytecode(tmp_path):
     _do_test(tmp_path, *BYTECODE_TEST)
 
 
-def test_zip_include_packages(tmp_path):
+def test_zip_include_packages(tmp_path) -> None:
     """Provides test cases for ModuleFinder class."""
     _do_test(
         tmp_path,
         *SUB_PACKAGE_TEST,
         zip_exclude_packages=["*"],
         zip_include_packages=["p"],
+        zip_include_all_packages=False,
     )
 
 
-def test_zip_exclude_packages(tmp_path):
+def test_zip_exclude_packages(tmp_path) -> None:
     """Provides test cases for ModuleFinder class."""
     _do_test(
         tmp_path,
         *SUB_PACKAGE_TEST,
         zip_exclude_packages=["p"],
         zip_include_packages=["*"],
+        zip_include_all_packages=True,
     )
